*( WHEDATE.CMD--Create and return a variable PV_BETW)
*( that contains a WHERE clause specifying a DATE range.)
*( It displays a snap file named WHEDATE.SNP to collect)
*( beginning and ending dates. Dates left null are shown as  */*/*.) 
*( Before running, you can set default values by setting PV_DATE1)
*( to a beginning date and PV_DATE2 to an ending date. When)
*( you run WHEDATE.CMD include the following three parameters)
*( in USING clause:  ...USING scrnline, scrnpos, datecol) 
*( SCRNLINE--screen line number (1 to 19) to display snap file.)
*( SCRNPOS--position (1 to 14) on the line to display snap file.)
*( DATECOL--name of the DATE column for the WHERE clause.)
*( Example:  RUN whedate.cmd USING 10,10 'transdate')
*( Then use PV_BETW in a command like this:)
*( Example:  SELECT * FROM transmaster &pv_betw)
*( WHEDATE.CMD requires the snap file WHEDATE.SNP and)
*( returns the WHERE clause in the variable PV_BETW. It stores)
*( the original environment and snaps the original screen. Then it)
*( restores the screen and environment at the end of the program.)
SNAP tmp.snp  *( Snap the current screen.)
SET ERROR VAR sv_errv
*( Use CVAL to store current environment to restore at the end.)
SET VAR lv_oldmess = (CVAL('MESSAGE')), +
  lv_olderr = (CVAL('ERROR')), oldmany = (CVAL('MANY')) 
SET VAR vbar TEXT = (CHAR(219)), vbar = (SFIL(.vbar,24)), +
  lv_dateT TEXT = '*/*/*', lv_org_row INTEGER = .%1, +
  lv_org_col INTEGER = .%2, lv_column TEXT = .%3, +
  pv_date1 DATE, pv_date2 DATE, +
  pv_betw TEXT = ( 'WHERE' & .lv_column ), +
  lv_r3 = (.lv_org_row + 3), lv_r4 = (.lv_org_row + 4), +
  lv_c5 = (.lv_org_col + 5), lv_c30 = (.lv_org_col + 30), +
  lv_c40 = (.lv_org_col + 40)
SET MESSAGES OFF; SET ERROR MESSAGES OFF
DEBUG SET MESSAGES ON; DEBUG SET ERROR MESSAGES ON
*( Change the MANY setting so you can clear percent variables.)
SET MANY=*
CLEAR VAR %1, %2, %3
SET MANY=%
CLS; DISPLAY whedate.snp AT .lv_org_row .lv_org_col
WRITE ' Enter Beginning Date: ' AT .lv_r3 .lv_c5 white ON gray
WRITE '          ' AT .lv_r3 .lv_c30  *( 10 spaces inside quotes.)
WRITE '    Enter Ending Date: ' AT .lv_r4 .lv_c5 white ON gray
WRITE '          ' AT .lv_r4 .lv_c30  *( 10 spaces inside quotes.)
LABEL date1
WRITE .vbar AT .lv_r3 .lv_c40 gray
FILLIN pv_date1=10 AT .lv_r3 .lv_c30 EDIT
IF sv_errv <> 0 THEN
  WRITE ' <--Invalid DATE.' AT .lv_r3 .lv_c40 gray ON black BLINK
  PAUSE 2
  GOTO date1
ENDIF
SHOW VAR pv_date1=10 AT .lv_r3 .lv_c30
SET VAR lv_last = (LASTKEY(0))
IF lv_last = '[Esc]' OR lv_last = '[Up]' OR lv_last = '[PgUp]' THEN
  SET VAR pv_betw = ' '
  GOTO goback
ENDIF
IF pv_date1 IS NULL THEN
  WRITE .lv_datet AT .lv_r3 .lv_c30
ENDIF
LABEL date2
WRITE .vbar AT .lv_r4 .lv_c40 gray
FILLIN pv_date2=10 AT .lv_r4 .lv_c30 edit
IF sv_errv <> 0 THEN
  WRITE ' <--Invalid DATE.' AT .lv_r4 .lv_c40 gray ON black BLINK
  PAUSE 2; GOTO date2
ENDIF
SHOW VAR pv_date2=10 AT .lv_r4 .lv_c30
SET VAR lv_last = (LASTKEY(0))
IF lv_last = '[Esc]' OR lv_last = '[Up]' OR lv_last = '[PgUp]' THEN
  GOTO date1
ENDIF
IF pv_date2 IS NULL THEN; WRITE .lv_datet AT .lv_r4 .lv_c30
ENDIF
*( Check for both dates null.)
LABEL both_null
IF pv_date1 IS NULL AND pv_date2 IS NULL THEN
  SET VAR pv_betw = (.pv_betw & 'IS NOT NULL' ), +
    pv_date1 TEXT = .lv_datet, pv_date2 TEXT = .lv_datet
  GOTO goback
ENDIF
*( Check for only an ending date.)
IF pv_date1 IS NULL AND pv_date2 IS NOT NULL THEN
  SET VAR pv_betw = (.pv_betw & '<=' & CTXT(.pv_date2)), +
    pv_date1 TEXT = .lv_datet
  GOTO goback
ENDIF
*( Check for only a beginning date.)
IF pv_date1 IS NOT NULL AND pv_date2 IS NULL THEN
  SET VAR pv_betw = (.pv_betw & '>=' & CTXT(.pv_date1) ), +
    pv_date2 TEXT = .lv_datet
  GOTO goback
ENDIF
*( Both dates are present. Check them.)
LABEL no_null
IF pv_date1 = pv_date2 THEN
  SET VAR pv_betw = (.pv_betw & '=' & CTXT(.pv_date1))
  GOTO goback
ENDIF
*( Check for beginning date bigger than ending date.)
IF pv_date1 > .pv_date2 THEN
  PAUSE 1 USING +
    'Beginning date is after ending date, so all dates included.'
  SET VAR pv_date1 = NULL, pv_date2 = NULL 
  GOTO both_null
ENDIF
SET VAR pv_betw = (.pv_betw & 'BETW' & CTXT(.pv_date1) +
  & 'AND' & CTXT(.pv_date2))
LABEL goback
CLS; DISPLAY tmp.snp  *( Redisplay the current screen.)
DEL tmp.snp
SET ERROR MESSAGES .lv_olderr; SET MESSAGES .lv_oldmess
CLEAR VAR lv%, pv_date%, vbar, sv_errv
SET MANY=.oldmany; CLEAR VAR oldmany
RETURN

